==> java-cxf-spring-server-generator-0.11.0.tgz: package/test-output/junit5/operations-v2.yml/src/test/java/com/example/Test2ApiTest.java <==
package com.example;

import static org.junit.jupiter.api.Assertions.*;

import javax.ws.rs.core.Response;

import org.apache.cxf.endpoint.Server;
import org.apache.cxf.jaxrs.client.JAXRSClientFactory;
import org.apache.cxf.jaxrs.client.WebClient;
import org.apache.cxf.jaxrs.spring.JAXRSServerFactoryBeanDefinitionParser.SpringJAXRSServerFactoryBean;
import org.apache.cxf.transport.local.LocalConduit;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit.jupiter.SpringExtension;

@ExtendWith(SpringExtension.class)
@ContextConfiguration(classes = { TestConfiguration.class })
public class Test2ApiTest {
	
	private static Server server;
	private com.example.Test2Api api;
	
	@Autowired
	private SpringJAXRSServerFactoryBean serverFactory;

	@BeforeEach
	public void setup() throws Exception {
		server = serverFactory.create();
		api = JAXRSClientFactory.create(TestConfiguration.ENDPOINT_ADDRESS, com.example.Test2Api.class, TestConfiguration.defaultProviders());
		WebClient.getConfig(api).getRequestContext().put(LocalConduit.DIRECT_DISPATCH, Boolean.TRUE);
	}
	
	@AfterEach
	public void destroy() throws Exception {
		server.stop();
		server.destroy();
	}
	
	@Test
	public void postTest2Test() {

		Response response = this.api.postTest2();
		assertNotNull(response);
	}

}

==> java-cxf-spring-server-generator-0.12.1.tgz: package/test-output/junit5/operations-v2.yml/src/test/java/com/example/Test2ApiTest.java <==
package com.example;

import static org.junit.jupiter.api.Assertions.*;

import javax.ws.rs.core.Response;

import org.apache.cxf.endpoint.Server;
import org.apache.cxf.jaxrs.client.JAXRSClientFactory;
import org.apache.cxf.jaxrs.client.WebClient;
import org.apache.cxf.jaxrs.spring.JAXRSServerFactoryBeanDefinitionParser.SpringJAXRSServerFactoryBean;
import org.apache.cxf.transport.local.LocalConduit;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit.jupiter.SpringExtension;

@ExtendWith(SpringExtension.class)
@ContextConfiguration(classes = { TestConfiguration.class })
public class Test2ApiTest {
	
	private Server server;
	private com.example.Test2Api api;
	
	@Autowired
	private SpringJAXRSServerFactoryBean serverFactory;

	@BeforeEach
	public void setup() throws Exception {
		server = serverFactory.create();
		api = JAXRSClientFactory.create(TestConfiguration.ENDPOINT_ADDRESS, com.example.Test2Api.class, TestConfiguration.defaultProviders());
		WebClient.getConfig(api).getRequestContext().put(LocalConduit.DIRECT_DISPATCH, Boolean.TRUE);
	}
	
	@AfterEach
	public void destroy() throws Exception {
		server.stop();
		server.destroy();
	}
	
	@Test
	public void postTest2Test() {

		Response response = this.api.postTest2();
		assertNotNull(response);
	}

}
